bloritsch 2003/07/30 12:25:36
Modified: csframework/src/cs AbstractLogEnabled.cs Attributes.cs
IServiceManager.cs ServiceException.cs cs.csproj
Removed: csframework/src/cs IContext.cs
Log:
add in some interfaces
Revision Changes Path
1.2 +1 -1 avalon-sandbox/csframework/src/cs/AbstractLogEnabled.cs
Index: AbstractLogEnabled.cs
===================================================================
RCS file: /home/cvs/avalon-sandbox/csframework/src/cs/AbstractLogEnabled.cs,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -r1.1 -r1.2
--- AbstractLogEnabled.cs 27 Jun 2003 20:52:02 -0000 1.1
+++ AbstractLogEnabled.cs 30 Jul 2003 19:25:36 -0000 1.2
@@ -54,7 +54,7 @@
/// The Utility class to allow construction of easy components
/// that will perform logging.
/// </summary>
- public abstract class AbstractLogEnabled
+ public abstract class AbstractLogEnabled : ILogEnabled
{
// Base ILogger instance
private ILogger m_logger;
1.7 +1 -29 avalon-sandbox/csframework/src/cs/Attributes.cs
Index: Attributes.cs
===================================================================
RCS file: /home/cvs/avalon-sandbox/csframework/src/cs/Attributes.cs,v
retrieving revision 1.6
retrieving revision 1.7
diff -u -r1.6 -r1.7
--- Attributes.cs 29 Jul 2003 16:59:55 -0000 1.6
+++ Attributes.cs 30 Jul 2003 19:25:36 -0000 1.7
@@ -94,7 +94,7 @@
/// <summary>
/// String prperty to use to look up the dependency from the
- /// <see cref="IServiceManager"/>
+ /// <see cref="ILookupManager"/>
/// </summary>
public string key;
@@ -126,33 +126,5 @@
///</summary>
[AttributeUsage(AttributeTargets.Class,AllowMultiple=false)]
public sealed class AvalonComponent : Attribute
- {}
-
- /// <summary>
- /// Mark a method as the configure method in a component.
- /// </summary>
- [AttributeUsage(AttributeTargets.Method,AllowMultiple=false)]
- public sealed class AvalonConfiguration : Attribute
- {}
-
- /// <summary>
- /// Mark a method as the contextualize method in a component.
- /// </summary>
- [AttributeUsage(AttributeTargets.Method,AllowMultiple=false)]
- public sealed class AvalonLookup : Attribute
- {}
-
- /// <summary>
- /// Mark a method as the initialize method in a component.
- /// </summary>
- [AttributeUsage(AttributeTargets.Method,AllowMultiple=false)]
- public sealed class AvalonInitialize : Attribute
- {}
-
- /// <summary>
- /// Mark a method as the dispose method in a component.
- /// </summary>
- [AttributeUsage(AttributeTargets.Method,AllowMultiple=false)]
- public sealed class AvalonDispose : Attribute
{}
}
1.2 +4 -4 avalon-sandbox/csframework/src/cs/IServiceManager.cs
Index: cs.csproj
===================================================================
RCS file: /home/cvs/avalon-sandbox/csframework/src/cs/cs.csproj,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -r1.1 -r1.2
--- cs.csproj 8 Jul 2003 17:18:55 -0000 1.1
+++ cs.csproj 30 Jul 2003 19:25:36 -0000 1.2
@@ -1,224 +1,219 @@
-<VisualStudioProject>
- <CSHARP
- ProjectType = "Local"
- ProductVersion = "7.10.3077"
- SchemaVersion = "2.0"
- ProjectGuid = "{C9D1D4DB-C3DF-4230-8ECE-9C253D09B369}"
- >
- <Build>
- <Settings
- ApplicationIcon = ""
- AssemblyKeyContainerName = ""
- AssemblyName = "cs"
- AssemblyOriginatorKeyFile = ""
- DefaultClientScript = "JScript"
- DefaultHTMLPageLayout = "Grid"
- DefaultTargetSchema = "IE50"
- DelaySign = "false"
- OutputType = "Exe"
- PreBuildEvent = ""
- PostBuildEvent = ""
- RootNamespace = "cs"
- RunPostBuildEvent = "OnBuildSuccess"
- StartupObject = ""
- >
- <Config
- Name = "Debug"
- AllowUnsafeBlocks = "false"
- BaseAddress = "285212672"
- CheckForOverflowUnderflow = "false"
- ConfigurationOverrideFile = ""
- DefineConstants = ""
- DocumentationFile = ""
- DebugSymbols = "true"
- FileAlignment = "4096"
- IncrementalBuild = "false"
- NoStdLib = "false"
- NoWarn = ""
- Optimize = "false"
- OutputPath = "bin\Debug\"
- RegisterForComInterop = "false"
- RemoveIntegerChecks = "false"
- TreatWarningsAsErrors = "false"
- WarningLevel = "1"
- />
- <Config
- Name = "Release"
- AllowUnsafeBlocks = "false"
- BaseAddress = "285212672"
- CheckForOverflowUnderflow = "false"
- ConfigurationOverrideFile = ""
- DefineConstants = ""
- DocumentationFile = ""
- DebugSymbols = "false"
- FileAlignment = "4096"
- IncrementalBuild = "false"
- NoStdLib = "false"
- NoWarn = ""
- Optimize = "false"
- OutputPath = "bin\Release\"
- RegisterForComInterop = "false"
- RemoveIntegerChecks = "false"
- TreatWarningsAsErrors = "false"
- WarningLevel = "1"
- />
- </Settings>
- <References>
- <Reference
- Name = "System.XML"
- AssemblyName = "System.XML"
- HintPath =
"..\..\..\..\..\WINDOWS\Microsoft.NET\Framework\v1.1.4322\System.XML.dll"
- />
- <Reference
- Name = "System.Configuration.Install"
- AssemblyName = "System.Configuration.Install"
- HintPath =
"..\..\..\..\..\WINDOWS\Microsoft.NET\Framework\v1.1.4322\System.Configuration.Install.dll"
- />
- <Reference
- Name = "System"
- AssemblyName = "System"
- HintPath =
"..\..\..\..\..\WINDOWS\Microsoft.NET\Framework\v1.1.4322\System.dll"
- />
- <Reference
- Name = "log4net-net-1.1"
- AssemblyName = "log4net-net-1.1"
- HintPath = "..\..\bin\log4net-net-1.1.dll"
- />
- </References>
- </Build>
- <Files>
- <Include>
- <File
- RelPath = "AbstractConfiguration.cs"
- SubType = "Code"
- BuildAction = "Compile"
- />
- <File
- RelPath = "AbstractLogEnabled.cs"
- SubType = "Code"
- BuildAction = "Compile"
- />
- <File
- RelPath = "AssemblyInfo.cs"
- BuildAction = "Compile"
- />
- <File
- RelPath = "Attributes.cs"
- SubType = "Code"
- BuildAction = "Compile"
- />
- <File
- RelPath = "ConfigurationCollection.cs"
- SubType = "Code"
- BuildAction = "Compile"
- />
- <File
- RelPath = "ConfigurationException.cs"
- SubType = "Code"
- BuildAction = "Compile"
- />
- <File
- RelPath = "ConsoleLogger.cs"
- SubType = "Code"
- BuildAction = "Compile"
- />
- <File
- RelPath = "ContainerUtil.cs"
- SubType = "Code"
- BuildAction = "Compile"
- />
- <File
- RelPath = "ContextException.cs"
- SubType = "Code"
- BuildAction = "Compile"
- />
- <File
- RelPath = "Converter.cs"
- SubType = "Code"
- BuildAction = "Compile"
- />
- <File
- RelPath = "DefaultConfiguration.cs"
- SubType = "Code"
- BuildAction = "Compile"
- />
- <File
- RelPath = "DefaultConfigurationSectionHandler.cs"
- SubType = "Code"
- BuildAction = "Compile"
- />
- <File
- RelPath = "DefaultConfigurationSerializer.cs"
- SubType = "Code"
- BuildAction = "Compile"
- />
- <File
- RelPath = "DefaultContext.cs"
- SubType = "Code"
- BuildAction = "Compile"
- />
- <File
- RelPath = "DiagnosticsLogger.cs"
- SubType = "Code"
- BuildAction = "Compile"
- />
- <File
- RelPath = "IConfiguration.cs"
- SubType = "Code"
- BuildAction = "Compile"
- />
- <File
- RelPath = "IContext.cs"
- SubType = "Code"
- BuildAction = "Compile"
- />
- <File
- RelPath = "ILogger.cs"
- SubType = "Code"
- BuildAction = "Compile"
- />
- <File
- RelPath = "IServiceManager.cs"
- SubType = "Code"
- BuildAction = "Compile"
- />
- <File
- RelPath = "LifecycleDelegates.cs"
- SubType = "Code"
- BuildAction = "Compile"
- />
- <File
- RelPath = "Log4netLogger.cs"
- SubType = "Code"
- BuildAction = "Compile"
- />
- <File
- RelPath = "NullLogger.cs"
- SubType = "Code"
- BuildAction = "Compile"
- />
- <File
- RelPath = "ParameterException.cs"
- SubType = "Code"
- BuildAction = "Compile"
- />
- <File
- RelPath = "Parameters.cs"
- SubType = "Code"
- BuildAction = "Compile"
- />
- <File
- RelPath = "RuntimeSerializer.cs"
- SubType = "Code"
- BuildAction = "Compile"
- />
- <File
- RelPath = "ServiceException.cs"
- SubType = "Code"
- BuildAction = "Compile"
- />
- </Include>
- </Files>
- </CSHARP>
-</VisualStudioProject>
-
+<VisualStudioProject>
+ <CSHARP
+ ProjectType = "Local"
+ ProductVersion = "7.10.3077"
+ SchemaVersion = "2.0"
+ ProjectGuid = "{C9D1D4DB-C3DF-4230-8ECE-9C253D09B369}"
+ >
+ <Build>
+ <Settings
+ ApplicationIcon = ""
+ AssemblyKeyContainerName = ""
+ AssemblyName = "cs"
+ AssemblyOriginatorKeyFile = ""
+ DefaultClientScript = "JScript"
+ DefaultHTMLPageLayout = "Grid"
+ DefaultTargetSchema = "IE50"
+ DelaySign = "false"
+ OutputType = "Exe"
+ PreBuildEvent = ""
+ PostBuildEvent = ""
+ RootNamespace = "cs"
+ RunPostBuildEvent = "OnBuildSuccess"
+ StartupObject = ""
+ >
+ <Config
+ Name = "Debug"
+ AllowUnsafeBlocks = "false"
+ BaseAddress = "285212672"
+ CheckForOverflowUnderflow = "false"
+ ConfigurationOverrideFile = ""
+ DefineConstants = ""
+ DocumentationFile = ""
+ DebugSymbols = "true"
+ FileAlignment = "4096"
+ IncrementalBuild = "false"
+ NoStdLib = "false"
+ NoWarn = ""
+ Optimize = "false"
+ OutputPath = "bin\Debug\"
+ RegisterForComInterop = "false"
+ RemoveIntegerChecks = "false"
+ TreatWarningsAsErrors = "false"
+ WarningLevel = "1"
+ />
+ <Config
+ Name = "Release"
+ AllowUnsafeBlocks = "false"
+ BaseAddress = "285212672"
+ CheckForOverflowUnderflow = "false"
+ ConfigurationOverrideFile = ""
+ DefineConstants = ""
+ DocumentationFile = ""
+ DebugSymbols = "false"
+ FileAlignment = "4096"
+ IncrementalBuild = "false"
+ NoStdLib = "false"
+ NoWarn = ""
+ Optimize = "false"
+ OutputPath = "bin\Release\"
+ RegisterForComInterop = "false"
+ RemoveIntegerChecks = "false"
+ TreatWarningsAsErrors = "false"
+ WarningLevel = "1"
+ />
+ </Settings>
+ <References>
+ <Reference
+ Name = "System.XML"
+ AssemblyName = "System.Xml"
+ HintPath =
"..\..\..\..\..\WINDOWS\Microsoft.NET\Framework\v1.1.4322\System.XML.dll"
+ />
+ <Reference
+ Name = "System.Configuration.Install"
+ AssemblyName = "System.Configuration.Install"
+ HintPath =
"..\..\..\..\..\WINDOWS\Microsoft.NET\Framework\v1.1.4322\System.Configuration.Install.dll"
+ />
+ <Reference
+ Name = "System"
+ AssemblyName = "System"
+ HintPath =
"..\..\..\..\..\WINDOWS\Microsoft.NET\Framework\v1.1.4322\System.dll"
+ />
+ <Reference
+ Name = "log4net-net-1.1"
+ AssemblyName = "log4net-net-1.1"
+ HintPath = "..\..\bin\log4net-net-1.1.dll"
+ />
+ <Reference
+ Name = "System.Data"
+ AssemblyName = "System.Data"
+ HintPath =
"..\..\..\..\..\WINDOWS\Microsoft.NET\Framework\v1.1.4322\System.Data.dll"
+ />
+ </References>
+ </Build>
+ <Files>
+ <Include>
+ <File
+ RelPath = "AbstractConfiguration.cs"
+ SubType = "Code"
+ BuildAction = "Compile"
+ />
+ <File
+ RelPath = "AbstractLogEnabled.cs"
+ SubType = "Code"
+ BuildAction = "Compile"
+ />
+ <File
+ RelPath = "AssemblyInfo.cs"
+ BuildAction = "Compile"
+ />
+ <File
+ RelPath = "Attributes.cs"
+ SubType = "Code"
+ BuildAction = "Compile"
+ />
+ <File
+ RelPath = "ConfigurationCollection.cs"
+ SubType = "Code"
+ BuildAction = "Compile"
+ />
+ <File
+ RelPath = "ConfigurationException.cs"
+ SubType = "Code"
+ BuildAction = "Compile"
+ />
+ <File
+ RelPath = "ConsoleLogger.cs"
+ SubType = "Code"
+ BuildAction = "Compile"
+ />
+ <File
+ RelPath = "ContainerUtil.cs"
+ SubType = "Code"
+ BuildAction = "Compile"
+ />
+ <File
+ RelPath = "Converter.cs"
+ SubType = "Code"
+ BuildAction = "Compile"
+ />
+ <File
+ RelPath = "DefaultConfiguration.cs"
+ SubType = "Code"
+ BuildAction = "Compile"
+ />
+ <File
+ RelPath = "DefaultConfigurationSectionHandler.cs"
+ SubType = "Code"
+ BuildAction = "Compile"
+ />
+ <File
+ RelPath = "DefaultConfigurationSerializer.cs"
+ SubType = "Code"
+ BuildAction = "Compile"
+ />
+ <File
+ RelPath = "DiagnosticsLogger.cs"
+ SubType = "Code"
+ BuildAction = "Compile"
+ />
+ <File
+ RelPath = "IConfigurable.cs"
+ SubType = "Code"
+ BuildAction = "Compile"
+ />
+ <File
+ RelPath = "IConfiguration.cs"
+ SubType = "Code"
+ BuildAction = "Compile"
+ />
+ <File
+ RelPath = "IContext.cs"
+ SubType = "Code"
+ BuildAction = "Compile"
+ />
+ <File
+ RelPath = "ILoggable.cs"
+ SubType = "Code"
+ BuildAction = "Compile"
+ />
+ <File
+ RelPath = "ILogger.cs"
+ SubType = "Code"
+ BuildAction = "Compile"
+ />
+ <File
+ RelPath = "ILookupEnabled.cs"
+ SubType = "Code"
+ BuildAction = "Compile"
+ />
+ <File
+ RelPath = "IServiceManager.cs"
+ SubType = "Code"
+ BuildAction = "Compile"
+ />
+ <File
+ RelPath = "Log4netLogger.cs"
+ SubType = "Code"
+ BuildAction = "Compile"
+ />
+ <File
+ RelPath = "NullLogger.cs"
+ SubType = "Code"
+ BuildAction = "Compile"
+ />
+ <File
+ RelPath = "RuntimeSerializer.cs"
+ SubType = "Code"
+ BuildAction = "Compile"
+ />
+ <File
+ RelPath = "ServiceException.cs"
+ SubType = "Code"
+ BuildAction = "Compile"
+ />
+ </Include>
+ </Files>
+ </CSHARP>
+</VisualStudioProject>
+
---------------------------------------------------------------------
To unsubscribe, e-mail: [EMAIL PROTECTED]
For additional commands, e-mail: [EMAIL PROTECTED]
Index: IServiceManager.cs
===================================================================
RCS file: /home/cvs/avalon-sandbox/csframework/src/cs/IServiceManager.cs,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -r1.1 -r1.2
--- IServiceManager.cs 27 Jun 2003 20:52:02 -0000 1.1
+++ IServiceManager.cs 30 Jul 2003 19:25:36 -0000 1.2
@@ -51,7 +51,7 @@
namespace Apache.AvalonFramework
{
/// <summary>
/// A <c>IServiceManager</c> selects components based on a
/// role. The contract is that all the components implement the
/// differing roles and there is one component per role.
/// <para>
@@ -62,7 +62,7 @@
/// nuances of the performance is different.
/// </para>
/// </summary>
- public interface IServiceManager
+ public interface ILookupManager
{
/// <summary>
/// Gets the component associated with the given role.
@@ -81,12 +81,12 @@
/// <summary>
/// Return the component when you are finished with it.
/// This allows the <see cref="IServiceManager"/> to handle
/// the End-Of-Life Lifecycle events associated with the component.
/// </summary>
/// <remarks>
/// Please note, that no Exceptions should be thrown at this point.
- /// This is to allow easy use of the <see cref="IServiceManager"/>
system without
+ /// This is to allow easy use of the <see cref="ILookupManager"/>
system without
/// having to trap Exceptions on a release.
/// </remarks>
@@ -51,7 +51,7 @@
{
/// <summary>
- /// A <c>IServiceManager</c> selects components based on a
+ /// A <c>ILookupManager</c> selects components based on a
/// role. The contract is that all the components implement the
/// differing roles and there is one component per role.
@@ -81,12 +81,12 @@
/// <summary>
/// Return the component when you are finished with it.
- /// This allows the <see cref="IServiceManager"/> to handle
+ /// This allows the <see cref="ILookupManager"/> to handle
/// the End-Of-Life Lifecycle events associated with the component.
/// </summary>
/// <param name="component">The component we are releasing.</param>
1.2 +16 -16 avalon-sandbox/csframework/src/cs/ServiceException.cs
Index: ServiceException.cs
===================================================================
RCS file: /home/cvs/avalon-sandbox/csframework/src/cs/ServiceException.cs,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -r1.1 -r1.2
--- ServiceException.cs 27 Jun 2003 20:52:02 -0000 1.1
+++ ServiceException.cs 30 Jul 2003 19:25:36 -0000 1.2
@@ -55,62 +55,62 @@
/// The Exception thrown to indicate a problem with service.
/// </summary>
/// <remarks>
- /// It is usually thrown by <see cref="IServiceManager"/>
+ /// It is usually thrown by <see cref="ILookupManager"/>
/// </remarks>
- public class ServiceException: Exception
+ public class LookupException: Exception
{
- private const string ROLE_NAME_SERIALIZATION =
"service-exception-role";
+ private const string ROLE_NAME_SERIALIZATION = "lookup-exception-role";
private string role;
/// <summary>
/// Constructs a new <c>ServiceException</c> instance.
/// </summary>
- public ServiceException(): this(null)
+ public LookupException(): this(null)
{
}
/// <summary>
/// Constructs a new <c>ServiceException</c> instance.
/// </summary>
/// <param name="message">The Detail message for this
exception.</param>
- public ServiceException(string message): this(null, message)
+ public LookupException(string message): this(null, message)
{
}
/// <summary>
/// Constructs a new <c>ServiceException</c> instance.
/// </summary>
/// <param name="role">The Role that caused the exception.</param>
/// <param name="message">The Detail message for this
exception.</param>
- public ServiceException(string role, string message): this(role,
message, null)
+ public LookupException(string role, string message): this(role,
message, null)
{
}
/// <summary>
/// Constructs a new <c>ServiceException</c> instance.
/// </summary>
/// <param name="message">The Detail message for this
exception.</param>
/// <param name="inner">The Root cause of the exception.</param>
- public ServiceException(string message, Exception inner): this(null,
message, inner)
+ public LookupException(string message, Exception inner): this(null,
message, inner)
{
}
/// <summary>
/// Constructs a new <c>ServiceException</c> instance.
/// </summary>
/// <param name="role">The Role that caused the exception.</param>
/// <param name="message">The Detail message for this
exception.</param>
/// <param name="inner">The Root cause of the exception.</param>
- public ServiceException(string role, string message, Exception inner):
base(message, inner)
+ public LookupException(string role, string message, Exception inner):
base(message, inner)
{
this.role = role;
}
/// <summary>
/// Constructs a new <see cref="ServiceException"/> instance.
/// </summary>
- public ServiceException(SerializationInfo info, StreamingContext
context): base(info, context)
+ public LookupException(SerializationInfo info, StreamingContext
context): base(info, context)
{
info.AddValue(ROLE_NAME_SERIALIZATION, role);
}
@@ -129,7 +129,7 @@
/// <summary>
/// Populates the <see cref="SerializationInfo"/> object with
- /// the data needed to serialize the <see cref="ServiceException"/>
object.
+ /// the data needed to serialize the <see cref="LookupException"/>
object.
/// </summary>
/// <param name="info"></param>
@@ -55,62 +55,62 @@
private string role;
/// <summary>
- /// Constructs a new <c>ServiceException</c> instance.
+ /// Constructs a new <c>LookupException</c> instance.
/// </summary>
@@ -55,62 +55,62 @@
}
/// <summary>
- /// Constructs a new <c>ServiceException</c> instance.
+ /// Constructs a new <c>LookupException</c> instance.
/// </summary>
/// <param name="message">The Detail message for this
@@ -55,62 +55,62 @@
}
/// <summary>
- /// Constructs a new <c>ServiceException</c> instance.
+ /// Constructs a new <c>LookupException</c> instance.
/// </summary>
/// <param name="role">The Role that caused the exception.</param>
@@ -55,62 +55,62 @@
}
/// <summary>
- /// Constructs a new <c>ServiceException</c> instance.
+ /// Constructs a new <c>LookupException</c> instance.
/// </summary>
/// <param name="message">The Detail message for this
@@ -55,62 +55,62 @@
}
/// <summary>
- /// Constructs a new <c>ServiceException</c> instance.
+ /// Constructs a new <c>LookupException</c> instance.
/// </summary>
/// <param name="role">The Role that caused the exception.</param>
@@ -55,62 +55,62 @@
}
/// <summary>
- /// Constructs a new <see cref="ServiceException"/> instance.
+ /// Constructs a new <see cref="LookupException"/> instance.
/// </summary>
/// <param name="context"></param>
1.2 +219 -224 avalon-sandbox/csframework/src/cs/cs.csproj